@@ -10,6 +10,18 @@ class PushDataHandler(object):
         self.table = table
         self.queue_configs = queue_configs
 
+    def start_rebuild_table(self):
+        message = build_push_message(PUSH_ACTION_REBUILD_START, self.database, self.table, {})
+        self.push_queue_message(message)
+
+    def end_rebuild_table(self):
+        message = build_push_message(PUSH_ACTION_REBUILD_END, self.database, self.table, {})
+        self.push_queue_message(message)
+
+    def drop_table(self):
+        message = build_push_message(PUSH_ACTION_DROP, self.database, self.table, {})
+        self.push_queue_message(message)
+
     def insert_data(self, data):
         message = build_push_message(PUSH_ACTION_INSERT, self.database, self.table, data)
         self.push_queue_message(message)
